(index)=

```{include} ../README.md
:end-before: <img
```

```{image} _static/tmuxp-demo.gif
:width: 100%

```

# Freeze a tmux session

```{include} ../README.md
:start-after: "# Freeze a tmux session"
```

```{toctree}
:maxdepth: 2
:hidden:

about
quickstart
cli/index
configuration/index
plugins/index

```

```{toctree}
:caption: Project
:hidden:

about_tmux
glossary
api
developing
history
GitHub <https://github.com/tmux-python/tmuxp>
```
